export default {
    "message": "Cannot use 'await' as identifier inside an async function",
    "column": 12,
    "index": 11,
    "lineNumber": 1
}
